OidcException class

Implemented types
Implementers

Constructors

OidcException({String message = 'Unspecified oidc exception.', dynamic cause})
const

Properties

cause → dynamic
The root cause of the oidc exception.
final
hashCode int
The hash code for this object.
no setterinherited
message String
A message describing the oidc exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited