LoginPrompt enum
Indicates the type of user interaction that is required to login.
Values
- consent → const LoginPrompt
-
This claim triggers the OAuth consent dialog after the user signs in. The dialog asks the user to grant permissions to the app.
const LoginPrompt('consent') - login → const LoginPrompt
-
This claim forces the user to enter his credentials on that request, which negates single sign-on.
const LoginPrompt('login') - none → const LoginPrompt
-
This claim ensures that the user isn't presented with any interactive prompt and should be paired with a
login hintto indicate which user must be signed in.If the request can't be completed silently via single sign-on, the login call returns an error.
const LoginPrompt('none') - selectAccount → const LoginPrompt
-
This claim shows the user an account selector, negating silent SSO but allowing the user to pick which account he intend to sign in with, without requiring credential entry.
const LoginPrompt('select_account')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LoginPrompt> - A constant List of the values in this enum, in order of their declaration.